#!/bin/sh

# Installs or uninstalls (if -u option is specified) custom pixbuf loader
# Place this script in the directory where the loader (checkboard.so) is.

# Get the directory where this script resides.
WORK_DIR=$(cd `dirname $0` && pwd) 
cd ${WORK_DIR}

PATH=/opt/gnome/bin:$PATH

CUSTOM_MODULE=checkboard.so
file ${CUSTOM_MODULE} | grep '32-bit' >/dev/null
if [ $? -eq 0 ]
then
#        echo "Attempting to find and update the list of 32-bit loaders..."
        QL_CMD=gdk-pixbuf-query-loaders
        LDR_32_BIT="yes"
else
#        echo "Attempting to find and update the list of 64-bit loaders..."
        QL_CMD=gdk-pixbuf-query-loaders-64
        LDR_32_BIT=""
fi

which ${QL_CMD} >/dev/null 2>&1
if [ $? -ne 0 ]
then
    QL_CMD=gdk-pixbuf-query-loaders

    which ${QL_CMD} >/dev/null 2>&1
    if [ $? -ne 0 ]
    then
        QL_CMD=gdk-pixbuf-query-loaders-32
    fi
fi 

# Find appropriate .loaders file to update
if [ -z ${GDK_PIXBUF_MODULE_FILE} ]
then
    if [ ! -d "${SYSCONFDIR}/gtk-2.0" ]
    then
        SYSCONFDIR=/etc
        if [ ! -d "${SYSCONFDIR}/gtk-2.0" ]  
        then
            SYSCONFDIR=/etc/opt/gnome
            if [ ! -d "${SYSCONFDIR}/gtk-2.0" ]  
            then
                echo "Unable to locate directory containing the .loaders file."
                exit 1
            fi
        fi
    fi

    LFILES=`find ${SYSCONFDIR}/gtk-2.0/ -name '*.loaders*'`
    LFILES_NONL=`echo ${LFILES} | tr -d \n`

    if [ -z "${LFILES_NONL}" ]; then
#        echo "Unable to locate the .loaders file in ${SYSCONFDIR}/gtk-2.0/ or its subdirectories."
#        exit 1
# This fallback action may help to circumvent the issues on Ubuntu and 
# similar systems where .loaders file is not present by default.
        LFILES="${SYSCONFDIR}/gtk-2.0/gdk-pixbuf.loaders"
        touch "${LFILES}" || exit 1
    fi
    
    which uname >/dev/null 2>&1 
    if [ $? -eq 0 ]; then
        # uname command is available
        ARCHNAME=`uname -m`
        GDK_PIXBUF_MODULE_FILE=`echo "${LFILES}" | grep ${ARCHNAME}`
    else
        # uname command is not available
        GDK_PIXBUF_MODULE_FILE=""
    fi
    
    if [ -z "${GDK_PIXBUF_MODULE_FILE}" ]; then
        # .loaders file has been found but not in a directory that has
        # architecture string in its name
        # If the loader is a 64-bit module, look for the the files with "64"
        # in their names.
        if [ -z "$LDR_32_BIT" ]; then    
            GDK_PIXBUF_MODULE_FILE=`echo "${LFILES}" | grep "64" | tail -1`
        fi
        
        # If nothing of the above helps to identify appropriate .loaders-file,
        # use the last file in the list.
        if [ -z "${GDK_PIXBUF_MODULE_FILE}" ]; then
            GDK_PIXBUF_MODULE_FILE=`echo "${LFILES}" | tail -1`
        fi
    fi
fi

echo "Updating the list of image loaders in ${GDK_PIXBUF_MODULE_FILE}"

if [ "$1" = '-u' ] 
then
#uninstall
#    echo "Uninstalling custom pixbuf loader..."
    ${QL_CMD} > ${GDK_PIXBUF_MODULE_FILE}
else
#install
#    echo "Installing custom pixbuf loader..."
    ${QL_CMD} ${CUSTOM_MODULE} >> ${GDK_PIXBUF_MODULE_FILE} 
fi
